@@ -51,7 +51,7 @@ sub new {
     my $self = bless({}, ref($class) || $class);
     my ($tree) = @_;
     $self->{evaluator} = WWW::Webrobot::Tree2Postfix -> new(
-        $unary_operator, $binary_operator, $predicate
+        $unary_operator, $binary_operator, $predicate, "and"
     );
     $self->{evaluator} -> tree2postfix($tree);
     return $self;
